]> git.sesse.net Git - nageru/blobdiff - theme.h
Change from RGBA to BGRA; slightly more Intel GPU-friendly, and Caspar uses that...
[nageru] / theme.h
diff --git a/theme.h b/theme.h
index b04050e51d05a6331b21d65409adda3311a61fa0..51107d6a5e088e3f6806c3785b6d1d8e1fdad85a 100644 (file)
--- a/theme.h
+++ b/theme.h
@@ -103,7 +103,7 @@ private:
 // the mixer, and communicates that state over to the actual YCbCrInput.
 class LiveInputWrapper {
 public:
// Note: <override_bounce> is irrelevant for PixelFormat_8BitRGBA.
        LiveInputWrapper(Theme *theme, movit::EffectChain *chain, bmusb::PixelFormat pixel_format, bool override_bounce, bool deinterlace);
 
        void connect_signal(int signal_num);
@@ -112,7 +112,7 @@ public:
        {
                if (deinterlace) {
                        return deinterlace_effect;
-               } else if (pixel_format == bmusb::PixelFormat_8BitRGBA) {
+               } else if (pixel_format == bmusb::PixelFormat_8BitBGRA) {
                        return rgba_inputs[0];
                } else {
                        return ycbcr_inputs[0];
@@ -103,7 +103,7 @@ private:
 class LiveInputWrapper {
 public:
-       // Note: <override_bounce> is irrelevant for PixelFormat_8BitRGBA.
+       // Note: <override_bounce> is irrelevant for PixelFormat_8BitBGRA.
        LiveInputWrapper(Theme *theme, movit::EffectChain *chain, bmusb::PixelFormat pixel_format, bool override_bounce, bool deinterlace);
 